|pypi| |actions| |codecov| |downloads|

edc-glucose
-----------------

Classes to manage glucose, ifg and ogtt


.. |pypi| image:: https://img.shields.io/pypi/v/edc-glucose.svg
    :target: https://pypi.python.org/pypi/edc-glucose

.. |actions| image:: https://github.com/clinicedc/edc-glucose/actions/workflows/build.yml/badge.svg
  :target: https://github.com/clinicedc/edc-glucose/actions/workflows/build.yml

.. |codecov| image:: https://codecov.io/gh/clinicedc/edc-glucose/branch/develop/graph/badge.svg
  :target: https://codecov.io/gh/clinicedc/edc-glucose

.. |downloads| image:: https://pepy.tech/badge/edc-blood-results
   :target: https://pepy.tech/project/edc-glucose
